# hierTS <img src="https://icai.ai/wp-content/uploads/2020/01/AIRLabAmsterdam-10-6-gecomprimeerd-transparant.png" width="300" alt="Airlab Amsterdam" align="right"> 
[![PyPi version](https://img.shields.io/pypi/v/hierts)](https://pypi.org/project/hierts/)
[![Python version](https://img.shields.io/pypi/pyversions/hierts)](https://docs.conda.io/en/latest/miniconda.html)

_Hierachical Time Series_ (hierTS) is a lightweight package that offers hierarchical forecasting reconciliation techniques to Python users.

For more details, [read the docs](https://hierts.readthedocs.io/en/latest/index.html) or check out the [examples](https://github.com/elephaint/hierts/tree/main/examples).

### Reference ###
The reconciliation methods that are currently in place are based on:
* Wickramasuriya, S. L., Athanasopoulos, G., & Hyndman, R. J. (2019). Optimal forecast reconciliation for hierarchical and grouped time series through trace minimization. Journal of the American Statistical Association, 114(526), 804-819.

### License ###
This project is licensed under the terms of the [Apache 2.0 license](https://github.com/elephaint/hierts/blob/main/LICENSE).

### Acknowledgements ###
This project was developed by [Airlab Amsterdam](https://icai.ai/airlab/).